from . import views

docs = {"tags": ["{{name}}"]}
routes = []
